@@ -1,4 +1,5 @@
 """Fixtures for tests."""
+import pathlib
 import typing as t
 
 import docutils.parsers.rst
@@ -11,6 +12,11 @@ if _extras.SPHINX_INSTALLED:
     import sphinx.application
 
 
+REPO_DIR = pathlib.Path(__file__).resolve().parents[1].resolve()
+TESTING_DIR = REPO_DIR / "testing"
+EXAMPLES_DIR = TESTING_DIR / "examples"
+
+
 @pytest.fixture(name="patch_docutils_directives_and_roles_dict")
 def _patch_docutils_directives_and_roles_dict_fixture(monkeypatch: pytest.MonkeyPatch) -> None:
     """Monkeypatch docutils' directives and roles state dicts.
